==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/V_VARSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BlockSet;
import io.ciera.tool.sql.ooaofooa.body.ForStmtSet;
import io.ciera.tool.sql.ooaofooa.body.impl.BlockSetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.ForStmtSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.DataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.DimensionsSetImpl;
import io.ciera.tool.sql.ooaofooa.event.CreateEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.CreateEventToInstanceSet;
import io.ciera.tool.sql.ooaofooa.event.E_GENSet;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateEventStatementSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateEventToInstanceSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.E_GENSetImpl;
import io.ciera.tool.sql.ooaofooa.instanceaccess.CreateSet;
import io.ciera.tool.sql.ooaofooa.instanceaccess.DeleteSet;
import io.ciera.tool.sql.ooaofooa.instanceaccess.impl.CreateSetImpl;
import io.ciera.tool.sql.ooaofooa.instanceaccess.impl.DeleteSetImpl;
import io.ciera.tool.sql.ooaofooa.invocation.OperationInvocationSet;
import io.ciera.tool.sql.ooaofooa.invocation.impl.OperationInvocationSetImpl;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.RelateSet;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.RelateUsingSet;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.UnrelateSet;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.UnrelateUsingSet;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.impl.RelateSetImpl;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.impl.RelateUsingSetImpl;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.impl.UnrelateSetImpl;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.impl.UnrelateUsingSetImpl;
import io.ciera.tool.sql.ooaofooa.selection.ACT_FIOSet;
import io.ciera.tool.sql.ooaofooa.selection.ACT_SELSet;
import io.ciera.tool.sql.ooaofooa.selection.SelectFromInstancesWhereSet;
import io.ciera.tool.sql.ooaofooa.selection.impl.ACT_FIOSetImpl;
import io.ciera.tool.sql.ooaofooa.selection.impl.ACT_SELSetImpl;
import io.ciera.tool.sql.ooaofooa.selection.impl.SelectFromInstancesWhereSetImpl;
import io.ciera.tool.sql.ooaofooa.value.InstanceHandleSet;
import io.ciera.tool.sql.ooaofooa.value.InstanceReferenceSet;
import io.ciera.tool.sql.ooaofooa.value.InstanceSetReferenceSet;
import io.ciera.tool.sql.ooaofooa.value.OperationValueSet;
import io.ciera.tool.sql.ooaofooa.value.TransientValueReferenceSet;
import io.ciera.tool.sql.ooaofooa.value.TransientVarSet;
import io.ciera.tool.sql.ooaofooa.value.V_INSSet;
import io.ciera.tool.sql.ooaofooa.value.V_VAR;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.VariableLocationSet;
import io.ciera.tool.sql.ooaofooa.value.impl.InstanceHandleSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.InstanceReferenceSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.InstanceSetReferenceSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.OperationValueSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.TransientValueReferenceSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.TransientVarSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.V_INSSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.VariableLocationSetImpl;

import java.util.Arrays;
import java.util.List;


public class V_VARSetImpl extends InstanceSet<V_VARSet,V_VAR> implements V_VARSet {

    // attributes
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( V_VAR v_var : this ) v_var.setDT_ID( ref_DT_ID );
    }
    @Override
    public void setDeclared( boolean m_Declared ) throws XtumlException {
        for ( V_VAR v_var : this ) v_var.setDeclared( m_Declared );
    }
    @Override
    public void setBlock_ID( UniqueId ref_Block_ID ) throws XtumlException {
        for ( V_VAR v_var : this ) v_var.setBlock_ID( ref_Block_ID );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( V_VAR v_var : this ) v_var.setName( m_Name );
    }
    @Override
    public void setVar_ID( UniqueId m_Var_ID ) throws XtumlException {
        for ( V_VAR v_var : this ) v_var.setVar_ID( m_Var_ID );
    }


    // selections
    @Override
    public ForStmtSet R614_is_loop_variable_ForStmt() throws XtumlException {
        ForStmtSet forstmtset = new ForStmtSetImpl();
        for ( V_VAR v_var : this ) forstmtset.addAll( v_var.R614_is_loop_variable_ForStmt() );
        return forstmtset;
    }
    @Override
    public RelateSet R615_is_one_variable_Relate() throws XtumlException {
        RelateSet relateset = new RelateSetImpl();
        for ( V_VAR v_var : this ) relateset.addAll( v_var.R615_is_one_variable_Relate() );
        return relateset;
    }
    @Override
    public RelateSet R616_is_other_variable_Relate() throws XtumlException {
        RelateSet relateset = new RelateSetImpl();
        for ( V_VAR v_var : this ) relateset.addAll( v_var.R616_is_other_variable_Relate() );
        return relateset;
    }
    @Override
    public RelateUsingSet R617_is_one_variable_RelateUsing() throws XtumlException {
        RelateUsingSet relateusingset = new RelateUsingSetImpl();
        for ( V_VAR v_var : this ) relateusingset.addAll( v_var.R617_is_one_variable_RelateUsing() );
        return relateusingset;
    }
    @Override
    public RelateUsingSet R618_is_other_variable_RelateUsing() throws XtumlException {
        RelateUsingSet relateusingset = new RelateUsingSetImpl();
        for ( V_VAR v_var : this ) relateusingset.addAll( v_var.R618_is_other_variable_RelateUsing() );
        return relateusingset;
    }
    @Override
    public RelateUsingSet R619_is_using_variable_RelateUsing() throws XtumlException {
        RelateUsingSet relateusingset = new RelateUsingSetImpl();
        for ( V_VAR v_var : this ) relateusingset.addAll( v_var.R619_is_using_variable_RelateUsing() );
        return relateusingset;
    }
    @Override
    public UnrelateSet R620_is_one_variable_Unrelate() throws XtumlException {
        UnrelateSet unrelateset = new UnrelateSetImpl();
        for ( V_VAR v_var : this ) unrelateset.addAll( v_var.R620_is_one_variable_Unrelate() );
        return unrelateset;
    }
    @Override
    public UnrelateSet R621_is_other_variable_Unrelate() throws XtumlException {
        UnrelateSet unrelateset = new UnrelateSetImpl();
        for ( V_VAR v_var : this ) unrelateset.addAll( v_var.R621_is_other_variable_Unrelate() );
        return unrelateset;
    }
    @Override
    public UnrelateUsingSet R622_is_one_variable_UnrelateUsing() throws XtumlException {
        UnrelateUsingSet unrelateusingset = new UnrelateUsingSetImpl();
        for ( V_VAR v_var : this ) unrelateusingset.addAll( v_var.R622_is_one_variable_UnrelateUsing() );
        return unrelateusingset;
    }
    @Override
    public UnrelateUsingSet R623_is_other_variable_UnrelateUsing() throws XtumlException {
        UnrelateUsingSet unrelateusingset = new UnrelateUsingSetImpl();
        for ( V_VAR v_var : this ) unrelateusingset.addAll( v_var.R623_is_other_variable_UnrelateUsing() );
        return unrelateusingset;
    }
    @Override
    public UnrelateUsingSet R624_is_using_variable_UnrelateUsing() throws XtumlException {
        UnrelateUsingSet unrelateusingset = new UnrelateUsingSetImpl();
        for ( V_VAR v_var : this ) unrelateusingset.addAll( v_var.R624_is_using_variable_UnrelateUsing() );
        return unrelateusingset;
    }
    @Override
    public CreateSet R633_Create() throws XtumlException {
        CreateSet createset = new CreateSetImpl();
        for ( V_VAR v_var : this ) createset.addAll( v_var.R633_Create() );
        return createset;
    }
    @Override
    public DeleteSet R634_Delete() throws XtumlException {
        DeleteSet deleteset = new DeleteSetImpl();
        for ( V_VAR v_var : this ) deleteset.addAll( v_var.R634_Delete() );
        return deleteset;
    }
    @Override
    public ACT_SELSet R638_ACT_SEL() throws XtumlException {
        ACT_SELSet act_selset = new ACT_SELSetImpl();
        for ( V_VAR v_var : this ) act_selset.addAll( v_var.R638_ACT_SEL() );
        return act_selset;
    }
    @Override
    public ACT_FIOSet R639_ACT_FIO() throws XtumlException {
        ACT_FIOSet act_fioset = new ACT_FIOSetImpl();
        for ( V_VAR v_var : this ) act_fioset.addAll( v_var.R639_ACT_FIO() );
        return act_fioset;
    }
    @Override
    public ForStmtSet R652_is_set_variable_ForStmt() throws XtumlException {
        ForStmtSet forstmtset = new ForStmtSetImpl();
        for ( V_VAR v_var : this ) forstmtset.addAll( v_var.R652_is_set_variable_ForStmt() );
        return forstmtset;
    }
    @Override
    public SelectFromInstancesWhereSet R665_SelectFromInstancesWhere() throws XtumlException {
        SelectFromInstancesWhereSet selectfrominstanceswhereset = new SelectFromInstancesWhereSetImpl();
        for ( V_VAR v_var : this ) selectfrominstanceswhereset.addAll( v_var.R665_SelectFromInstancesWhere() );
        return selectfrominstanceswhereset;
    }
    @Override
    public OperationInvocationSet R667_is_target_of_OperationInvocation() throws XtumlException {
        OperationInvocationSet operationinvocationset = new OperationInvocationSetImpl();
        for ( V_VAR v_var : this ) operationinvocationset.addAll( v_var.R667_is_target_of_OperationInvocation() );
        return operationinvocationset;
    }
    @Override
    public CreateEventStatementSet R710_CreateEventStatement() throws XtumlException {
        CreateEventStatementSet createeventstatementset = new CreateEventStatementSetImpl();
        for ( V_VAR v_var : this ) createeventstatementset.addAll( v_var.R710_CreateEventStatement() );
        return createeventstatementset;
    }
    @Override
    public CreateEventToInstanceSet R711_CreateEventToInstance() throws XtumlException {
        CreateEventToInstanceSet createeventtoinstanceset = new CreateEventToInstanceSetImpl();
        for ( V_VAR v_var : this ) createeventtoinstanceset.addAll( v_var.R711_CreateEventToInstance() );
        return createeventtoinstanceset;
    }
    @Override
    public E_GENSet R712_E_GEN() throws XtumlException {
        E_GENSet e_genset = new E_GENSetImpl();
        for ( V_VAR v_var : this ) e_genset.addAll( v_var.R712_E_GEN() );
        return e_genset;
    }
    @Override
    public TransientValueReferenceSet R805_TransientValueReference() throws XtumlException {
        TransientValueReferenceSet transientvaluereferenceset = new TransientValueReferenceSetImpl();
        for ( V_VAR v_var : this ) transientvaluereferenceset.addAll( v_var.R805_TransientValueReference() );
        return transientvaluereferenceset;
    }
    @Override
    public InstanceReferenceSet R808_InstanceReference() throws XtumlException {
        InstanceReferenceSet instancereferenceset = new InstanceReferenceSetImpl();
        for ( V_VAR v_var : this ) instancereferenceset.addAll( v_var.R808_InstanceReference() );
        return instancereferenceset;
    }
    @Override
    public InstanceSetReferenceSet R809_InstanceSetReference() throws XtumlException {
        InstanceSetReferenceSet instancesetreferenceset = new InstanceSetReferenceSetImpl();
        for ( V_VAR v_var : this ) instancesetreferenceset.addAll( v_var.R809_InstanceSetReference() );
        return instancesetreferenceset;
    }
    @Override
    public InstanceHandleSet R814_is_a_InstanceHandle() throws XtumlException {
        InstanceHandleSet instancehandleset = new InstanceHandleSetImpl();
        for ( V_VAR v_var : this ) instancehandleset.add( v_var.R814_is_a_InstanceHandle() );
        return instancehandleset;
    }
    @Override
    public TransientVarSet R814_is_a_TransientVar() throws XtumlException {
        TransientVarSet transientvarset = new TransientVarSetImpl();
        for ( V_VAR v_var : this ) transientvarset.add( v_var.R814_is_a_TransientVar() );
        return transientvarset;
    }
    @Override
    public V_INSSet R814_is_a_V_INS() throws XtumlException {
        V_INSSet v_insset = new V_INSSetImpl();
        for ( V_VAR v_var : this ) v_insset.add( v_var.R814_is_a_V_INS() );
        return v_insset;
    }
    @Override
    public BlockSet R823_Block() throws XtumlException {
        BlockSet blockset = new BlockSetImpl();
        for ( V_VAR v_var : this ) blockset.add( v_var.R823_Block() );
        return blockset;
    }
    @Override
    public OperationValueSet R830_variable_OperationValue() throws XtumlException {
        OperationValueSet operationvalueset = new OperationValueSetImpl();
        for ( V_VAR v_var : this ) operationvalueset.addAll( v_var.R830_variable_OperationValue() );
        return operationvalueset;
    }
    @Override
    public VariableLocationSet R835_VariableLocation() throws XtumlException {
        VariableLocationSet variablelocationset = new VariableLocationSetImpl();
        for ( V_VAR v_var : this ) variablelocationset.addAll( v_var.R835_VariableLocation() );
        return variablelocationset;
    }
    @Override
    public DataTypeSet R848_has_DataType() throws XtumlException {
        DataTypeSet datatypeset = new DataTypeSetImpl();
        for ( V_VAR v_var : this ) datatypeset.add( v_var.R848_has_DataType() );
        return datatypeset;
    }
    @Override
    public DimensionsSet R849_may_have_Dimensions() throws XtumlException {
        DimensionsSet dimensionsset = new DimensionsSetImpl();
        for ( V_VAR v_var : this ) dimensionsset.addAll( v_var.R849_may_have_Dimensions() );
        return dimensionsset;
    }


    @Override
    public V_VAR nullElement() {
        return V_VARImpl.EMPTY_V_VAR;
    }

    @Override
    public V_VARSet emptySet() {
      return new V_VARSetImpl();
    }

    @Override
    public V_VARSet value() {
        return this;
    }

    @Override
    public List<V_VAR> elements() {
        V_VAR[] elements = toArray(new V_VAR[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/V_VARSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BlockSet;
import io.ciera.tool.sql.ooaofooa.body.ForStmtSet;
import io.ciera.tool.sql.ooaofooa.body.impl.BlockSetImpl;
import io.ciera.tool.sql.ooaofooa.body.impl.ForStmtSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.DataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.DimensionsSetImpl;
import io.ciera.tool.sql.ooaofooa.event.CreateEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.CreateEventToInstanceSet;
import io.ciera.tool.sql.ooaofooa.event.E_GENSet;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateEventStatementSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateEventToInstanceSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.E_GENSetImpl;
import io.ciera.tool.sql.ooaofooa.instanceaccess.CreateSet;
import io.ciera.tool.sql.ooaofooa.instanceaccess.DeleteSet;
import io.ciera.tool.sql.ooaofooa.instanceaccess.impl.CreateSetImpl;
import io.ciera.tool.sql.ooaofooa.instanceaccess.impl.DeleteSetImpl;
import io.ciera.tool.sql.ooaofooa.invocation.OperationInvocationSet;
import io.ciera.tool.sql.ooaofooa.invocation.impl.OperationInvocationSetImpl;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.RelateSet;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.RelateUsingSet;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.UnrelateSet;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.UnrelateUsingSet;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.impl.RelateSetImpl;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.impl.RelateUsingSetImpl;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.impl.UnrelateSetImpl;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.impl.UnrelateUsingSetImpl;
import io.ciera.tool.sql.ooaofooa.selection.ACT_FIOSet;
import io.ciera.tool.sql.ooaofooa.selection.ACT_SELSet;
import io.ciera.tool.sql.ooaofooa.selection.SelectFromInstancesWhereSet;
import io.ciera.tool.sql.ooaofooa.selection.impl.ACT_FIOSetImpl;
import io.ciera.tool.sql.ooaofooa.selection.impl.ACT_SELSetImpl;
import io.ciera.tool.sql.ooaofooa.selection.impl.SelectFromInstancesWhereSetImpl;
import io.ciera.tool.sql.ooaofooa.value.InstanceHandleSet;
import io.ciera.tool.sql.ooaofooa.value.InstanceReferenceSet;
import io.ciera.tool.sql.ooaofooa.value.InstanceSetReferenceSet;
import io.ciera.tool.sql.ooaofooa.value.OperationValueSet;
import io.ciera.tool.sql.ooaofooa.value.TransientValueReferenceSet;
import io.ciera.tool.sql.ooaofooa.value.TransientVarSet;
import io.ciera.tool.sql.ooaofooa.value.V_INSSet;
import io.ciera.tool.sql.ooaofooa.value.V_VAR;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.VariableLocationSet;
import io.ciera.tool.sql.ooaofooa.value.impl.InstanceHandleSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.InstanceReferenceSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.InstanceSetReferenceSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.OperationValueSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.TransientValueReferenceSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.TransientVarSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.V_INSSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.VariableLocationSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class V_VARSetImpl extends InstanceSet<V_VARSet,V_VAR> implements V_VARSet {

    public V_VARSetImpl() {
    }

    public V_VARSetImpl(Comparator<? super V_VAR> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setDeclared( boolean m_Declared ) throws XtumlException {
        for ( V_VAR v_var : this ) v_var.setDeclared( m_Declared );
    }
    @Override
    public void setBlock_ID( UniqueId ref_Block_ID ) throws XtumlException {
        for ( V_VAR v_var : this ) v_var.setBlock_ID( ref_Block_ID );
    }
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( V_VAR v_var : this ) v_var.setDT_ID( ref_DT_ID );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( V_VAR v_var : this ) v_var.setName( m_Name );
    }
    @Override
    public void setVar_ID( UniqueId m_Var_ID ) throws XtumlException {
        for ( V_VAR v_var : this ) v_var.setVar_ID( m_Var_ID );
    }


    // selections
    @Override
    public ForStmtSet R614_is_loop_variable_ForStmt() throws XtumlException {
        ForStmtSet forstmtset = new ForStmtSetImpl();
        for ( V_VAR v_var : this ) forstmtset.addAll( v_var.R614_is_loop_variable_ForStmt() );
        return forstmtset;
    }
    @Override
    public RelateSet R615_is_one_variable_Relate() throws XtumlException {
        RelateSet relateset = new RelateSetImpl();
        for ( V_VAR v_var : this ) relateset.addAll( v_var.R615_is_one_variable_Relate() );
        return relateset;
    }
    @Override
    public RelateSet R616_is_other_variable_Relate() throws XtumlException {
        RelateSet relateset = new RelateSetImpl();
        for ( V_VAR v_var : this ) relateset.addAll( v_var.R616_is_other_variable_Relate() );
        return relateset;
    }
    @Override
    public RelateUsingSet R617_is_one_variable_RelateUsing() throws XtumlException {
        RelateUsingSet relateusingset = new RelateUsingSetImpl();
        for ( V_VAR v_var : this ) relateusingset.addAll( v_var.R617_is_one_variable_RelateUsing() );
        return relateusingset;
    }
    @Override
    public RelateUsingSet R618_is_other_variable_RelateUsing() throws XtumlException {
        RelateUsingSet relateusingset = new RelateUsingSetImpl();
        for ( V_VAR v_var : this ) relateusingset.addAll( v_var.R618_is_other_variable_RelateUsing() );
        return relateusingset;
    }
    @Override
    public RelateUsingSet R619_is_using_variable_RelateUsing() throws XtumlException {
        RelateUsingSet relateusingset = new RelateUsingSetImpl();
        for ( V_VAR v_var : this ) relateusingset.addAll( v_var.R619_is_using_variable_RelateUsing() );
        return relateusingset;
    }
    @Override
    public UnrelateSet R620_is_one_variable_Unrelate() throws XtumlException {
        UnrelateSet unrelateset = new UnrelateSetImpl();
        for ( V_VAR v_var : this ) unrelateset.addAll( v_var.R620_is_one_variable_Unrelate() );
        return unrelateset;
    }
    @Override
    public UnrelateSet R621_is_other_variable_Unrelate() throws XtumlException {
        UnrelateSet unrelateset = new UnrelateSetImpl();
        for ( V_VAR v_var : this ) unrelateset.addAll( v_var.R621_is_other_variable_Unrelate() );
        return unrelateset;
    }
    @Override
    public UnrelateUsingSet R622_is_one_variable_UnrelateUsing() throws XtumlException {
        UnrelateUsingSet unrelateusingset = new UnrelateUsingSetImpl();
        for ( V_VAR v_var : this ) unrelateusingset.addAll( v_var.R622_is_one_variable_UnrelateUsing() );
        return unrelateusingset;
    }
    @Override
    public UnrelateUsingSet R623_is_other_variable_UnrelateUsing() throws XtumlException {
        UnrelateUsingSet unrelateusingset = new UnrelateUsingSetImpl();
        for ( V_VAR v_var : this ) unrelateusingset.addAll( v_var.R623_is_other_variable_UnrelateUsing() );
        return unrelateusingset;
    }
    @Override
    public UnrelateUsingSet R624_is_using_variable_UnrelateUsing() throws XtumlException {
        UnrelateUsingSet unrelateusingset = new UnrelateUsingSetImpl();
        for ( V_VAR v_var : this ) unrelateusingset.addAll( v_var.R624_is_using_variable_UnrelateUsing() );
        return unrelateusingset;
    }
    @Override
    public CreateSet R633_Create() throws XtumlException {
        CreateSet createset = new CreateSetImpl();
        for ( V_VAR v_var : this ) createset.addAll( v_var.R633_Create() );
        return createset;
    }
    @Override
    public DeleteSet R634_Delete() throws XtumlException {
        DeleteSet deleteset = new DeleteSetImpl();
        for ( V_VAR v_var : this ) deleteset.addAll( v_var.R634_Delete() );
        return deleteset;
    }
    @Override
    public ACT_SELSet R638_ACT_SEL() throws XtumlException {
        ACT_SELSet act_selset = new ACT_SELSetImpl();
        for ( V_VAR v_var : this ) act_selset.addAll( v_var.R638_ACT_SEL() );
        return act_selset;
    }
    @Override
    public ACT_FIOSet R639_ACT_FIO() throws XtumlException {
        ACT_FIOSet act_fioset = new ACT_FIOSetImpl();
        for ( V_VAR v_var : this ) act_fioset.addAll( v_var.R639_ACT_FIO() );
        return act_fioset;
    }
    @Override
    public ForStmtSet R652_is_set_variable_ForStmt() throws XtumlException {
        ForStmtSet forstmtset = new ForStmtSetImpl();
        for ( V_VAR v_var : this ) forstmtset.addAll( v_var.R652_is_set_variable_ForStmt() );
        return forstmtset;
    }
    @Override
    public SelectFromInstancesWhereSet R665_SelectFromInstancesWhere() throws XtumlException {
        SelectFromInstancesWhereSet selectfrominstanceswhereset = new SelectFromInstancesWhereSetImpl();
        for ( V_VAR v_var : this ) selectfrominstanceswhereset.addAll( v_var.R665_SelectFromInstancesWhere() );
        return selectfrominstanceswhereset;
    }
    @Override
    public OperationInvocationSet R667_is_target_of_OperationInvocation() throws XtumlException {
        OperationInvocationSet operationinvocationset = new OperationInvocationSetImpl();
        for ( V_VAR v_var : this ) operationinvocationset.addAll( v_var.R667_is_target_of_OperationInvocation() );
        return operationinvocationset;
    }
    @Override
    public CreateEventStatementSet R710_CreateEventStatement() throws XtumlException {
        CreateEventStatementSet createeventstatementset = new CreateEventStatementSetImpl();
        for ( V_VAR v_var : this ) createeventstatementset.addAll( v_var.R710_CreateEventStatement() );
        return createeventstatementset;
    }
    @Override
    public CreateEventToInstanceSet R711_CreateEventToInstance() throws XtumlException {
        CreateEventToInstanceSet createeventtoinstanceset = new CreateEventToInstanceSetImpl();
        for ( V_VAR v_var : this ) createeventtoinstanceset.addAll( v_var.R711_CreateEventToInstance() );
        return createeventtoinstanceset;
    }
    @Override
    public E_GENSet R712_E_GEN() throws XtumlException {
        E_GENSet e_genset = new E_GENSetImpl();
        for ( V_VAR v_var : this ) e_genset.addAll( v_var.R712_E_GEN() );
        return e_genset;
    }
    @Override
    public TransientValueReferenceSet R805_TransientValueReference() throws XtumlException {
        TransientValueReferenceSet transientvaluereferenceset = new TransientValueReferenceSetImpl();
        for ( V_VAR v_var : this ) transientvaluereferenceset.addAll( v_var.R805_TransientValueReference() );
        return transientvaluereferenceset;
    }
    @Override
    public InstanceReferenceSet R808_InstanceReference() throws XtumlException {
        InstanceReferenceSet instancereferenceset = new InstanceReferenceSetImpl();
        for ( V_VAR v_var : this ) instancereferenceset.addAll( v_var.R808_InstanceReference() );
        return instancereferenceset;
    }
    @Override
    public InstanceSetReferenceSet R809_InstanceSetReference() throws XtumlException {
        InstanceSetReferenceSet instancesetreferenceset = new InstanceSetReferenceSetImpl();
        for ( V_VAR v_var : this ) instancesetreferenceset.addAll( v_var.R809_InstanceSetReference() );
        return instancesetreferenceset;
    }
    @Override
    public InstanceHandleSet R814_is_a_InstanceHandle() throws XtumlException {
        InstanceHandleSet instancehandleset = new InstanceHandleSetImpl();
        for ( V_VAR v_var : this ) instancehandleset.add( v_var.R814_is_a_InstanceHandle() );
        return instancehandleset;
    }
    @Override
    public TransientVarSet R814_is_a_TransientVar() throws XtumlException {
        TransientVarSet transientvarset = new TransientVarSetImpl();
        for ( V_VAR v_var : this ) transientvarset.add( v_var.R814_is_a_TransientVar() );
        return transientvarset;
    }
    @Override
    public V_INSSet R814_is_a_V_INS() throws XtumlException {
        V_INSSet v_insset = new V_INSSetImpl();
        for ( V_VAR v_var : this ) v_insset.add( v_var.R814_is_a_V_INS() );
        return v_insset;
    }
    @Override
    public BlockSet R823_Block() throws XtumlException {
        BlockSet blockset = new BlockSetImpl();
        for ( V_VAR v_var : this ) blockset.add( v_var.R823_Block() );
        return blockset;
    }
    @Override
    public OperationValueSet R830_variable_OperationValue() throws XtumlException {
        OperationValueSet operationvalueset = new OperationValueSetImpl();
        for ( V_VAR v_var : this ) operationvalueset.addAll( v_var.R830_variable_OperationValue() );
        return operationvalueset;
    }
    @Override
    public VariableLocationSet R835_VariableLocation() throws XtumlException {
        VariableLocationSet variablelocationset = new VariableLocationSetImpl();
        for ( V_VAR v_var : this ) variablelocationset.addAll( v_var.R835_VariableLocation() );
        return variablelocationset;
    }
    @Override
    public DataTypeSet R848_has_DataType() throws XtumlException {
        DataTypeSet datatypeset = new DataTypeSetImpl();
        for ( V_VAR v_var : this ) datatypeset.add( v_var.R848_has_DataType() );
        return datatypeset;
    }
    @Override
    public DimensionsSet R849_may_have_Dimensions() throws XtumlException {
        DimensionsSet dimensionsset = new DimensionsSetImpl();
        for ( V_VAR v_var : this ) dimensionsset.addAll( v_var.R849_may_have_Dimensions() );
        return dimensionsset;
    }


    @Override
    public V_VAR nullElement() {
        return V_VARImpl.EMPTY_V_VAR;
    }

    @Override
    public V_VARSet emptySet() {
      return new V_VARSetImpl();
    }

    @Override
    public V_VARSet emptySet(Comparator<? super V_VAR> comp) {
      return new V_VARSetImpl(comp);
    }

    @Override
    public V_VARSet value() {
        return this;
    }

    @Override
    public List<V_VAR> elements() {
        V_VAR[] elements = toArray(new V_VAR[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
